pub struct DynamicMap { /* private fields */ }Expand description
An unordered mapping between reflected values.
Implementations
Sourceimpl DynamicMap
impl DynamicMap
Sourcepub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicMap.
Panics
Panics if the given type is not a TypeInfo::Map.
Sourcepub fn insert<K, V>(&mut self, key: K, value: V)where
K: PartialReflect,
V: PartialReflect,
pub fn insert<K, V>(&mut self, key: K, value: V)where
K: PartialReflect,
V: PartialReflect,
Inserts a typed key-value pair into the map.